@@ -1,6 +1,7 @@
 #' @importFrom tools file_path_sans_ext
 processing_monolix  <- function(project,model=NULL,treatment=NULL,parameter=NULL,regressor=NULL,
-                                output=NULL,group=NULL,r.data=TRUE,fim=NULL,create.model=TRUE, format.original=FALSE)
+                                output=NULL,group=NULL,r.data=TRUE,fim=NULL,create.model=TRUE, 
+                                format.original=FALSE, error.iov=TRUE)
 {
   ### processing_monolix
   #     takes a monolix project and extract information from
@@ -52,9 +53,9 @@ processing_monolix  <- function(project,model=NULL,treatment=NULL,parameter=NULL
   names.proj <- NULL
   if (r.data==TRUE) {
     #    datas <- readDatamlx(infoProject=infoProject)
-    datas <- readDatamlx(project=project, obs.rows=format.original)
+    datas <- readDatamlx(project=project, obs.rows=format.original, error.iov=error.iov)
     if (format.original) {
-      datao <- readDatamlx(project=project, out.data=TRUE)
+      datao <- readDatamlx(project=project, out.data=TRUE, error.iov=error.iov)
       datao$obsRows <- datas$obsRows
       datas$format.original <- datao
     }
@@ -174,7 +175,7 @@ processing_monolix  <- function(project,model=NULL,treatment=NULL,parameter=NULL
   r <- readPopEstimate(infoProject$resultFolder,fim)
   names.proj <- unique(c(names.proj, unlist(lapply(r,names))))
   names.param <- unique(setdiff(unlist(lapply(parameter,names)),c("id", "time", "occ", "pop")))
-  test2 <- !(names.param %in% names.proj)
+  test2 <- !(names.param %in% gsub("_pop","",names.proj))
   if (any(test2))
     warning(paste0("Parameter ",names.param[test2]," is not used in the project\n"), call.=FALSE)
   
